langtools/src/jdk.compiler/share/classes/com/sun/source/tree/ProvidesTree.java
changeset 42407 f3702cff2933
parent 36526 3b41f1c69604
--- a/langtools/src/jdk.compiler/share/classes/com/sun/source/tree/ProvidesTree.java	Wed Nov 23 16:16:36 2016 +0000
+++ b/langtools/src/jdk.compiler/share/classes/com/sun/source/tree/ProvidesTree.java	Thu Dec 01 09:02:42 2016 +0000
@@ -25,6 +25,8 @@
 
 package com.sun.source.tree;
 
+import java.util.List;
+
 /**
  * A tree node for a 'provides' directive in a module declaration.
  *
@@ -43,8 +45,8 @@
     ExpressionTree getServiceName();
 
     /**
      * Returns the name of the implementation type being provided.
      * @return the name of the implementation type being provided
      */
-    ExpressionTree getImplementationName();
+    List<? extends ExpressionTree> getImplementationNames();
 }
@@ -43,8 +45,8 @@
 
     /**
-     * Returns the name of the implementation type being provided.
-     * @return the name of the implementation type being provided
+     * Returns the names of the implementation types being provided.
+     * @return the names of the implementation types being provided
      */